@@ -62,13 +62,14 @@ Geometry::Geometry(const Geometry& geometry,const CopyOp& copyop):
         _vertexAttribList.push_back(copyop(vitr->get()));
     }
 
-    if ((copyop.getCopyFlags() & osg::CopyOp::DEEP_COPY_ARRAYS))
+    if ((copyop.getCopyFlags() & osg::CopyOp::DEEP_COPY_ARRAYS) || (copyop.getCopyFlags() & osg::CopyOp::DEEP_COPY_PRIMITIVES))
     {
         if (_useVertexBufferObjects)
         {
             // copying of arrays doesn't set up buffer objects so we'll need to force
-            // Geometry to assign these, we'll do this by switching off VBO's then renabling them.
-            setUseVertexBufferObjects(false);
+            // Geometry to assign these, we'll do this by changing the cached value to false then re-enabling.
+            // note do not use setUseVertexBufferObjects(false) as it might modify Arrays that we have not deep-copied.
+            _useVertexBufferObjects = false;
             setUseVertexBufferObjects(true);
         }
     }
@@ -201,7 +202,7 @@ void Geometry::setTexCoordArrayList(const ArrayList& arrayList)
             itr != _texCoordList.end();
             ++itr)
         {
-            addVertexBufferObjectIfRequired(itr->get());
+           if (itr->get()) addVertexBufferObjectIfRequired(itr->get());
         }
     }
 }
@@ -244,7 +245,7 @@ void Geometry::setVertexAttribArrayList(const ArrayList& arrayList)
             itr != _vertexAttribList.end();
             ++itr)
         {
-            addVertexBufferObjectIfRequired(itr->get());
+            if (itr->get()) addVertexBufferObjectIfRequired(itr->get());
         }
     }
 }
@@ -261,7 +262,8 @@ bool Geometry::addPrimitiveSet(PrimitiveSet* primitiveset)
         dirtyBound();
         return true;
     }
-    OSG_WARN<<"Warning: invalid index i or primitiveset passed to osg::Geometry::addPrimitiveSet(i,primitiveset), ignoring call."<<std::endl;
+
+    OSG_WARN<<"Warning: invalid primitiveset passed to osg::Geometry::addPrimitiveSet(i, primitiveset), ignoring call."<<std::endl;
     return false;
 }
 
@@ -443,7 +445,7 @@ bool Geometry::getDrawElementsList(DrawElementsList& drawElementsList) const
 
 void Geometry::addVertexBufferObjectIfRequired(osg::Array* array)
 {
-    if (_useVertexBufferObjects)
+    if (_useVertexBufferObjects && array->getBinding()==Array::BIND_PER_VERTEX)
     {
         if (!array->getVertexBufferObject())
         {
@@ -1041,7 +1043,7 @@ Geometry* osg::createTexturedQuadGeometry(const Vec3& corner,const Vec3& widthVe
     geom->setNormalArray(normals, osg::Array::BIND_OVERALL);
 
 
-#if defined(OSG_GLES1_AVAILABLE) || !defined(OSG_GLES2_AVAILABLE)
+#if defined(OSG_GLES1_AVAILABLE) || defined(OSG_GLES2_AVAILABLE)
     DrawElementsUByte* elems = new DrawElementsUByte(PrimitiveSet::TRIANGLES);
     elems->push_back(0);
     elems->push_back(1);
