@@ -25,6 +25,7 @@
 
 #include <osg/Notify>
 #include <osg/Endian>
+#include <osg/Types>
 
 #include <osgDB/Registry>
 #include <osgDB/ReadFile>
@@ -43,23 +44,6 @@
 #include <sys/stat.h>
 
 #include <string.h>
-
-
-#if defined(_WIN32) && !defined(__MINGW32__) && (!defined(_MSC_VER) || _MSC_VER<1600)
-
-typedef unsigned __int8 uint8_t;
-typedef unsigned __int16 uint16_t;
-typedef unsigned __int32 uint32_t;
-typedef signed __int8 int8_t;
-typedef signed __int16 int16_t;
-typedef signed __int32 int32_t;
-
-#else
-
-#include <stdint.h>
-
-#endif
-
 #include <memory>
 
 struct STLOptionsStruct {
