@@ -228,11 +228,12 @@ void ARBQuerySupport::checkQuery(osg::Stats* stats, osg::State* state,
                 // If the high bits on any of the timestamp bits are
                 // different then the counters may have wrapped.
                 const int hiShift = (tbits - 1);
-                const GLuint64 hiMask = 1 << hiShift;
+                const GLuint64 one = 1;
+                const GLuint64 hiMask = one << hiShift;
                 const GLuint64 sum = (beginTimestamp >> hiShift)
                     + (endTimestamp >> hiShift) + (gpuTimestamp >> hiShift);
                 if (sum == 1 || sum == 2) {
-                    const GLuint64 wrapAdd = 1 << tbits;
+                    const GLuint64 wrapAdd = one << tbits;
                     // Counter wrapped between begin and end?
                     if (beginTimestamp > endTimestamp)
                     {
@@ -368,6 +369,10 @@ Renderer::Renderer(osg::Camera* camera):
     _sceneView[0] = new osgUtil::SceneView;
     _sceneView[1] = new osgUtil::SceneView;
 
+    // each SceneView to have their own FrameStamp to avoid thread conflicts with the Viewer's main FrameStamp
+    _sceneView[0]->setFrameStamp(new osg::FrameStamp());
+    _sceneView[1]->setFrameStamp(new osg::FrameStamp());
+
     osg::Camera* masterCamera = _camera->getView() ? _camera->getView()->getCamera() : camera;
 
     osg::StateSet* global_stateset = 0;
@@ -528,7 +533,15 @@ void Renderer::updateSceneView(osgUtil::SceneView* sceneView)
     osgDB::ImagePager* imagePager = view ? view->getImagePager() : 0;
     sceneView->getCullVisitor()->setImageRequestHandler(imagePager);
 
-    sceneView->setFrameStamp(view ? view->getFrameStamp() : state->getFrameStamp());
+
+    if (view && view->getFrameStamp())
+    {
+        (*const_cast<osg::FrameStamp*>(sceneView->getFrameStamp())) = *(view->getFrameStamp());
+    }
+    else if (state->getFrameStamp())
+    {
+        (*const_cast<osg::FrameStamp*>(sceneView->getFrameStamp())) = *(state->getFrameStamp());
+    }
 
     osg::DisplaySettings* ds = _camera->getDisplaySettings() ?  _camera->getDisplaySettings() :
                                ((view &&view->getDisplaySettings()) ?  view->getDisplaySettings() :  osg::DisplaySettings::instance().get());
@@ -627,8 +640,7 @@ void Renderer::cull()
         if (view) sceneView->setFusionDistance(view->getFusionDistanceMode(), view->getFusionDistanceValue());
 
         osg::Stats* stats = sceneView->getCamera()->getStats();
-        osg::State* state = sceneView->getState();
-        const osg::FrameStamp* fs = state->getFrameStamp();
+        const osg::FrameStamp* fs = sceneView->getFrameStamp();
         unsigned int frameNumber = fs ? fs->getFrameNumber() : 0;
 
         // do cull traversal
@@ -640,6 +652,7 @@ void Renderer::cull()
         osg::Timer_t afterCullTick = osg::Timer::instance()->tick();
 
 #if 0
+        osg::State* state = sceneView->getState();
         if (sceneView->getDynamicObjectCount()==0 && state->getDynamicObjectRenderingCompletedCallback())
         {
             // OSG_NOTICE<<"Completed in cull"<<std::endl;
